Crate gema_texto

Crate gema_texto 

gema_texto parses gemtext and renders html.

This library powers blog and page, so it makes some decisions on for those projects. Here’s how each line is handled:

  • Headings and the content under them is wrapped in a <section> tag.
  • All text lines are <p>, even empty ones.
  • URLs are wrapped in a <p>
  • Alt Text is supported for preformatted-toggles, and is written as the aria-label of the <pre> tag.
  • Consecutive list items are wrapped in a <ul> and rendered as <li> tags.
  • Quotes are wrapped in a single <blockquote>

Modules

gemini_parser
html_renderer